time

package
v1.7.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 20, 2021 License: BSD-3-Clause Imports: 3 Imported by: 1

Documentation

Index

Constants

const (
	CLOCK_BOOTTIME            = 7
	CLOCK_BOOTTIME_ALARM      = 9
	CLOCK_MONOTONIC           = 1
	CLOCK_MONOTONIC_COARSE    = 6
	CLOCK_MONOTONIC_RAW       = 4
	CLOCK_PROCESS_CPUTIME_ID  = 2
	CLOCK_REALTIME            = 0
	CLOCK_REALTIME_ALARM      = 8
	CLOCK_REALTIME_COARSE     = 5
	CLOCK_TAI                 = 11
	CLOCK_THREAD_CPUTIME_ID   = 3
	TIMER_ABSTIME             = 1
	TIME_UTC                  = 1
	X_ATFILE_SOURCE           = 1
	X_BITS_TIME_H             = 1
	X_BITS_TYPESIZES_H        = 1
	X_BITS_TYPES_H            = 1
	X_BITS_TYPES_LOCALE_T_H   = 1
	X_BITS_TYPES___LOCALE_T_H = 1
	X_BSD_SIZE_T_             = 0
	X_BSD_SIZE_T_DEFINED_     = 0
	X_DEFAULT_SOURCE          = 1
	X_FEATURES_H              = 1
	X_FILE_OFFSET_BITS        = 64
	X_GCC_SIZE_T              = 0
	X_LP64                    = 1
	X_POSIX_C_SOURCE          = 200809
	X_POSIX_SOURCE            = 1
	X_SIZET_                  = 0
	X_SIZE_T                  = 0
	X_SIZE_T_                 = 0
	X_SIZE_T_DECLARED         = 0
	X_SIZE_T_DEFINED          = 0
	X_SIZE_T_DEFINED_         = 0
	X_STDC_PREDEF_H           = 1
	X_STRUCT_TIMESPEC         = 1
	X_SYS_CDEFS_H             = 1
	X_SYS_SIZE_T_H            = 0
	X_TIME_H                  = 1
	X_T_SIZE                  = 0
	X_T_SIZE_                 = 0
	Linux                     = 1
	Unix                      = 1
)

Variables

var CAPI = map[string]struct{}{}

Functions

This section is empty.

Types

type Clock_t

type Clock_t = X__clock_t /* clock_t.h:7:19 */

Returned by `clock'.

type Clockid_t

type Clockid_t = X__clockid_t /* clockid_t.h:7:21 */

Clock ID used in clock and timer functions.

type Itimerspec

type Itimerspec = struct {
	Fit_interval struct {
		Ftv_sec  X__time_t
		Ftv_nsec X__syscall_slong_t
	}
	Fit_value struct {
		Ftv_sec  X__time_t
		Ftv_nsec X__syscall_slong_t
	}

} /* struct_itimerspec.h:8:1 */

POSIX.1b structure for timer start values and intervals.

type Locale_t

type Locale_t = X__locale_t /* locale_t.h:24:20 */

type Pid_t

type Pid_t = X__pid_t /* time.h:54:17 */

type Ptrdiff_t

type Ptrdiff_t = int64 /* <builtin>:3:26 */

type Size_t

type Size_t = uint64 /* <builtin>:9:23 */

type Time_t

type Time_t = X__time_t /* time_t.h:7:18 */

Returned by `time'.

type Timer_t

type Timer_t = X__timer_t /* timer_t.h:7:19 */

Timer ID returned by `timer_create'.

type Timespec

type Timespec = struct {
	Ftv_sec  X__time_t
	Ftv_nsec X__syscall_slong_t

} /* struct_timespec.h:9:1 */

POSIX.1b structure for a time value. This is like a `struct timeval' but

has nanoseconds instead of microseconds.

type Tm

type Tm = struct {
	Ftm_sec   int32
	Ftm_min   int32
	Ftm_hour  int32
	Ftm_mday  int32
	Ftm_mon   int32
	Ftm_year  int32
	Ftm_wday  int32
	Ftm_yday  int32
	Ftm_isdst int32

	Ftm_gmtoff int64
	Ftm_zone   uintptr
	// contains filtered or unexported fields

} /* struct_tm.h:7:1 */

ISO C `broken-down time' structure.

type Wchar_t

type Wchar_t = int32 /* <builtin>:15:24 */

type X__blkcnt64_t

type X__blkcnt64_t = int64 /* types.h:178:30 */

type X__blkcnt_t

type X__blkcnt_t = int64 /* types.h:177:28 */

Type to count number of disk blocks.

type X__blksize_t

type X__blksize_t = int64 /* types.h:172:29 */

Type to represent block size.

type X__builtin_va_list

type X__builtin_va_list = uintptr /* <builtin>:47:14 */

type X__caddr_t

type X__caddr_t = uintptr /* types.h:201:14 */

type X__clock_t

type X__clock_t = int64 /* types.h:154:27 */ // Type of CPU usage counts.

type X__clockid_t

type X__clockid_t = int32 /* types.h:166:29 */

Clock ID used in clock and timer functions.

type X__daddr_t

type X__daddr_t = int32 /* types.h:162:27 */ // The type of a disk address.

type X__dev_t

type X__dev_t = uint64 /* types.h:143:25 */ // Type of device numbers.

type X__float128

type X__float128 = float64 /* <builtin>:48:21 */

type X__fsblkcnt64_t

type X__fsblkcnt64_t = uint64 /* types.h:182:32 */

type X__fsblkcnt_t

type X__fsblkcnt_t = uint64 /* types.h:181:30 */

Type to count file system blocks.

type X__fsfilcnt64_t

type X__fsfilcnt64_t = uint64 /* types.h:186:32 */

type X__fsfilcnt_t

type X__fsfilcnt_t = uint64 /* types.h:185:30 */

Type to count file system nodes.

type X__fsid_t

type X__fsid_t = struct{ F__val [2]int32 } /* types.h:153:26 */ // Type of file system IDs.

type X__fsword_t

type X__fsword_t = int64 /* types.h:189:28 */

Type of miscellaneous file system fields.

type X__gid_t

type X__gid_t = uint32 /* types.h:145:25 */ // Type of group identifications.

type X__id_t

type X__id_t = uint32 /* types.h:157:24 */ // General type for IDs.

type X__ino64_t

type X__ino64_t = uint64 /* types.h:147:27 */ // Type of file serial numbers (LFS).

type X__ino_t

type X__ino_t = uint64 /* types.h:146:25 */ // Type of file serial numbers.

type X__int8_t

type X__int8_t = int8 /* types.h:36:21 */

Fixed-size types, underlying types depend on word size and compiler.

type X__int16_t

type X__int16_t = int16 /* types.h:38:26 */

type X__int32_t

type X__int32_t = int32 /* types.h:40:20 */

type X__int64_t

type X__int64_t = int64 /* types.h:43:25 */

type X__int128_t added in v1.3.0

type X__int128_t = [2]int64 /* <builtin>:21:24 */ //TODO

type X__int_least8_t

type X__int_least8_t = X__int8_t /* types.h:51:18 */

Smallest types with at least a given width.

type X__int_least16_t

type X__int_least16_t = X__int16_t /* types.h:53:19 */

type X__int_least32_t

type X__int_least32_t = X__int32_t /* types.h:55:19 */

type X__int_least64_t

type X__int_least64_t = X__int64_t /* types.h:57:19 */

type X__intmax_t

type X__intmax_t = int64 /* types.h:71:18 */

Largest integral types.

type X__intptr_t

type X__intptr_t = int64 /* types.h:204:25 */

Duplicates info from stdint.h but this is used in unistd.h.

type X__key_t

type X__key_t = int32 /* types.h:163:25 */ // Type of an IPC key.

type X__locale_struct

type X__locale_struct = struct {
	F__locales       [13]uintptr
	F__ctype_b       uintptr
	F__ctype_tolower uintptr
	F__ctype_toupper uintptr
	F__names         [13]uintptr

} /* __locale_t.h:28:1 */

type X__locale_t

type X__locale_t = uintptr /* __locale_t.h:42:32 */

type X__loff_t

type X__loff_t = X__off64_t /* types.h:200:19 */ // Type of file sizes and offsets (LFS).

These few don't really vary by system, they always correspond

to one of the other defined types.

type X__mode_t

type X__mode_t = uint32 /* types.h:148:26 */ // Type of file attribute bitmasks.
type X__nlink_t = uint64 /* types.h:149:27 */ // Type of file link counts.

type X__off64_t

type X__off64_t = int64 /* types.h:151:27 */ // Type of file sizes and offsets (LFS).

type X__off_t

type X__off_t = int64 /* types.h:150:25 */ // Type of file sizes and offsets.

type X__pid_t

type X__pid_t = int32 /* types.h:152:25 */ // Type of process identifications.

type X__quad_t

type X__quad_t = int64 /* types.h:62:18 */

quad_t is also 64 bits.

type X__rlim64_t

type X__rlim64_t = uint64 /* types.h:156:28 */ // Type for resource measurement (LFS).

type X__rlim_t

type X__rlim_t = uint64 /* types.h:155:26 */ // Type for resource measurement.

type X__sig_atomic_t

type X__sig_atomic_t = int32 /* types.h:212:13 */

C99: An integer type that can be accessed as an atomic entity,

even in the presence of asynchronous interrupts.
It is not currently necessary for this to be machine-specific.

type X__socklen_t

type X__socklen_t = uint32 /* types.h:207:23 */

Duplicate info from sys/socket.h.

type X__ssize_t

type X__ssize_t = int64 /* types.h:191:27 */ // Type of a byte count, or error.

type X__suseconds_t

type X__suseconds_t = int64 /* types.h:160:31 */ // Signed count of microseconds.

type X__syscall_slong_t

type X__syscall_slong_t = int64 /* types.h:194:33 */

Signed long type used in system calls.

type X__syscall_ulong_t

type X__syscall_ulong_t = uint64 /* types.h:196:33 */

Unsigned long type used in system calls.

type X__time_t

type X__time_t = int64 /* types.h:158:26 */ // Seconds since the Epoch.

type X__timer_t

type X__timer_t = uintptr /* types.h:169:12 */

Timer ID returned by `timer_create'.

type X__u_char

type X__u_char = uint8 /* types.h:30:23 */

Convenience types.

type X__u_int

type X__u_int = uint32 /* types.h:32:22 */

type X__u_long

type X__u_long = uint64 /* types.h:33:27 */

type X__u_quad_t

type X__u_quad_t = uint64 /* types.h:63:27 */

type X__u_short

type X__u_short = uint16 /* types.h:31:28 */

type X__uid_t

type X__uid_t = uint32 /* types.h:144:25 */ // Type of user identifications.

type X__uint8_t

type X__uint8_t = uint8 /* types.h:37:23 */

type X__uint16_t

type X__uint16_t = uint16 /* types.h:39:28 */

type X__uint32_t

type X__uint32_t = uint32 /* types.h:41:22 */

type X__uint64_t

type X__uint64_t = uint64 /* types.h:44:27 */

type X__uint128_t added in v1.3.0

type X__uint128_t = [2]uint64 /* <builtin>:22:25 */ //TODO

type X__uint_least8_t

type X__uint_least8_t = X__uint8_t /* types.h:52:19 */

type X__uint_least16_t

type X__uint_least16_t = X__uint16_t /* types.h:54:20 */

type X__uint_least32_t

type X__uint_least32_t = X__uint32_t /* types.h:56:20 */

type X__uint_least64_t

type X__uint_least64_t = X__uint64_t /* types.h:58:20 */

type X__uintmax_t

type X__uintmax_t = uint64 /* types.h:72:27 */

type X__useconds_t

type X__useconds_t = uint32 /* types.h:159:30 */ // Count of microseconds.

Jump to